@@ -678,7 +678,7 @@ FeedWriter.prototype = {
    * @returns The display name of the application represented by the file.
    */
   _getFileDisplayName: function getFileDisplayName(file) {
-//@line 699 "/builds/slave/linux_build/build/suite/feeds/src/FeedWriter.js"
+//@line 699 "/builds/slave/rel-comm-191-lnx-bld/build/suite/feeds/src/FeedWriter.js"
     var url = this._ioSvc.newFileURI(file).QueryInterface(Components.interfaces.nsIURL);
     return url.fileName;
   },
@@ -732,9 +732,9 @@ FeedWriter.prototype = {
           // XXXben - we need to compare this with the running instance executable
           //          just don't know how to do that via script...
           // XXXmano TBD: can probably add this to nsIShellService
-//@line 758 "/builds/slave/linux_build/build/suite/feeds/src/FeedWriter.js"
+//@line 758 "/builds/slave/rel-comm-191-lnx-bld/build/suite/feeds/src/FeedWriter.js"
           if (fp.file.leafName != "seamonkey-bin") {
-//@line 761 "/builds/slave/linux_build/build/suite/feeds/src/FeedWriter.js"
+//@line 761 "/builds/slave/rel-comm-191-lnx-bld/build/suite/feeds/src/FeedWriter.js"
             this._initMenuItemWithFile(this._contentSandbox.selectedAppMenuItem,
                                        this._selectedApp);
 
@@ -953,7 +953,7 @@ FeedWriter.prototype = {
 
     menuItem = null;
 
-//@line 1001 "/builds/slave/linux_build/build/suite/feeds/src/FeedWriter.js"
+//@line 1001 "/builds/slave/rel-comm-191-lnx-bld/build/suite/feeds/src/FeedWriter.js"
 
     if (menuItem) {
       this._contentSandbox.defaultHandlerMenuItem = menuItem;
@@ -1231,7 +1231,6 @@ FeedWriter.prototype = {
           wccr.setAutoHandler(this._getMimeTypeForFeedType(feedType), handler);
 
         this._window.location.href = handler.getHandlerURI(this._window.location.href);
-        return;
       }
     }
     else {
